Hyalus is a testing tool for software verification, designed as a standalone tool as well as a tool that integrates with [pytest](https://docs.pytest.org/en/7.2.x/).

# Getting Started

See [Intro to hyalus](GETTING_STARTED.md).

# Contributing

See [Contribution Guidelines](CONTRIBUTING.md).

# Code of Conduct

See [Code of Conduct](CODE_OF_CONDUCT.md).

# License

Copyright David McConnell and others, 2023.

Distributed under the terms of the [MIT license](https://opensource.org/license/mit/), hyalus is free and open source software.
